
var generateAttributionMap = function(selector, attributioncolour) {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        chrome.tabs.sendMessage(tabs[0].id, {action: 'generateAttributionMap', selector: selector, attributioncolour: attributioncolour});
    });
};

var maskDomContent = function(maskregex) {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        chrome.tabs.sendMessage(tabs[0].id, {action: 'maskDomContent', maskregex: maskregex});
    });
};

(function() {

	var headers, header, i,
		debugmode = false,
		requestFilter = {urls:["<all_urls>"], types: ["main_frame", "sub_frame", "stylesheet", "script", "image", "object", "xmlhttprequest", "other"]},
		onHeadersReceivedHandler = function(details) {
			headers = details.responseHeaders;
			i = headers.length;
			while (i--) {
				header = headers[i].name.toLowerCase();
				if (header === 'frame-options'
						|| header === 'x-frame-options'
						|| header === 'content-security-policy'
						|| header === 'x-content-security-policy'
					) {
					headers.splice(i,1);
				}
			}
			return {responseHeaders: headers};
		},
		onBeforeRequestHandler = function(details) {
			var i, postBody;
			if (debugmode && /decibelinsight.net\/(i\/[0-9]+\/)?da\/\?type=/i.test(details.url)) {
				try {
					if (details.requestBody && details.requestBody.raw) {
						postBody = '';
						var arr = new Uint8Array(details.requestBody.raw[0].bytes),
							chunk = 0x8000,
							index = 0,
							length = arr.length,
							slice;
						while (index < length) {
							slice = arr.slice(index, Math.min(index + chunk, length));
							postBody += String.fromCharCode.apply(null, slice);
							index += chunk;
						}
					}
				} catch(e) {
				}
				if (details.type === 'ping') {
					chrome.tabs.query({}, function(tabs) {
						for (i=0; i<tabs.length; ++i) {
							chrome.tabs.sendMessage(tabs[i].id, {
								action: 'dataCollection',
								url: details.url,
								postBody: postBody
							});
						}
					});
				} else {
					chrome.tabs.sendMessage(details.tabId, {
						action: 'dataCollection',
						url: details.url,
						postBody: postBody
					});
				}
			}
		};

	chrome.storage.sync.get(['debugmode'], function(items) {
		debugmode = items.debugmode ? true : false;
	});

	chrome.storage.onChanged.addListener(function(changes) {
		if (changes.debugmode) {
			debugmode = changes.debugmode.newValue ? true : false;
		}
	});

	chrome.webRequest.onHeadersReceived.addListener( onHeadersReceivedHandler, requestFilter, ['responseHeaders', 'blocking'] );
	chrome.webRequest.onBeforeRequest.addListener( onBeforeRequestHandler, {urls: ["<all_urls>"], types: ["xmlhttprequest","ping"]}, ["blocking","requestBody"]);

})();

